@@ -16,19 +16,18 @@ from qobuzzz_dl.settings import Settings, getSettingsPath
 from qobuzzz_dl.model import Album, Track, Playlist, Artist
 
 __LOGO__ = '''
-              __                                        
-             /\ \                                       
-   __     ___\ \ \____  __  __  ____    ____    ____    
- /'__`\  / __`\ \ '__`\/\ \/\ \/\_ ,`\ /\_ ,`\ /\_ ,`\  
-/\ \L\ \/\ \L\ \ \ \L\ \ \ \_\ \/_/  /_\/_/  /_\/_/  /_ 
-\ \___, \ \____/\ \_,__/\ \____/ /\____\ /\____\ /\____\
- \/___/\ \/___/  \/___/  \/___/  \/____/ \/____/ \/____/
-      \ \_\                                             
-       \/_/                                             
-   
+  /$$$$$$            /$$                                              
+ /$$__  $$          | $$                                              
+| $$  \ $$  /$$$$$$ | $$$$$$$  /$$   /$$ /$$$$$$$$ /$$$$$$$$ /$$$$$$$$
+| $$  | $$ /$$__  $$| $$__  $$| $$  | $$|____ /$$/|____ /$$/|____ /$$/
+| $$  | $$| $$  \ $$| $$  \ $$| $$  | $$   /$$$$/    /$$$$/    /$$$$/ 
+| $$/$$ $$| $$  | $$| $$  | $$| $$  | $$  /$$__/    /$$__/    /$$__/  
+|  $$$$$$/|  $$$$$$/| $$$$$$$/|  $$$$$$/ /$$$$$$$$ /$$$$$$$$ /$$$$$$$$
+ \____ $$$ \______/ |_______/  \______/ |________/|________/|________/
+      \__/                                                            
        https://github.com/yaronzz/Qobuzzz-Media-Downloader 
 '''
-VERSION = '2021.3.3.1'
+VERSION = '2021.3.3.2'
 
 class Printf(object):
 
